@@ -59,9 +59,9 @@ pref("general.warnOnAboutConfig", true);
 pref("browser.bookmarks.max_backups",       5);
 
 pref("browser.cache.disk.enable",           true);
-//@line 63 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 63 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 pref("browser.cache.disk.capacity",         51200);
-//@line 67 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 67 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 pref("browser.cache.memory.enable",         true);
 //pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
@@ -70,7 +70,7 @@ pref("browser.cache.disk_cache_ssl",        false);
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
-//@line 76 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 76 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -81,7 +81,7 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
-//@line 92 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 92 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
 // Fastback caching - if this pref is negative, then we calculate the number
 // of content viewers to cache based on the amount of available memory.
@@ -145,11 +145,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 156 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 156 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 159 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 159 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 161 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 161 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -162,16 +162,18 @@ pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.sanitize", true);
-//@line 176 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 176 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
-//@line 178 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 178 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
+
+//@line 186 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 185 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 193 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -184,7 +186,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 201 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 209 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -528,9 +530,9 @@ pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 545 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 553 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 547 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 555 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -579,7 +581,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 598 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 606 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -724,6 +726,7 @@ pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
 pref("network.IDN.whitelist.lu", true);
+pref("network.IDN.whitelist.lv", true);
 pref("network.IDN.whitelist.no", true);
 pref("network.IDN.whitelist.nu", true);
 pref("network.IDN.whitelist.nz", true);
@@ -752,6 +755,9 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// lk, Sri Lanka, .<Lanka> and .<Ilangai>
+pref("network.IDN.whitelist.xn--fzc2c9e2c", true);
+pref("network.IDN.whitelist.xn--xkc2al3hye2a", true);
 // qa, Qatar, .<Qatar>
 pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
@@ -761,11 +767,14 @@ pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true);
 pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
 pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
 pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// sy, Syria, .<Souria>
+pref("network.IDN.whitelist.xn--ogbpf8fl", true);
 // tw, Taiwan, <.Taiwan> with variants
 pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
 pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
+pref("network.IDN.whitelist.asia", true);
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
@@ -851,7 +860,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 875 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 890 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1272,15 +1281,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1693 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 1708 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
-//@line 2117 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2132 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
-//@line 2320 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2335 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
-//@line 2416 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2431 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
-//@line 2419 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2434 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1550,15 +1559,15 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2691 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2706 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
-//@line 2759 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2774 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
-//@line 2785 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2800 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
-//@line 2805 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2820 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
-//@line 2813 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2828 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1595,9 +1604,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2855 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2870 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
-//@line 2860 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2875 "/home/karma/src/firefox/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
